/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import com.sun.jersey.api.client.ClientResponse;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.opengroup.osdu.register.model.Topic;
import org.opengroup.osdu.register.util.AzureTestUtils;
import org.opengroup.osdu.register.util.RestDescriptor;

import java.util.ArrayList;
import java.util.List;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

public class TestListTopicsApi extends ListTopicsApiTest {

    @Before
    @Override
    public void setup() {
        this.testUtils = new AzureTestUtils();
    }

    @After
    @Override
    public void tearDown() {
        this.testUtils = null;
    }

    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String body = response.getEntity(String.class);
        java.lang.reflect.Type listType = new TypeToken<ArrayList<Topic>>() {
        }.getType();
        Gson gson = new Gson();
        List<Topic> messages = gson.fromJson(body, listType);
        assertTrue(messages.size() > 0);
        String topic = System.getProperty("TEST_TOPIC_NAME", System.getenv("TEST_TOPIC_NAME"));
        assertTrue(messages.stream().anyMatch(m -> m.name.equalsIgnoreCase(topic)));
    }

    @Test
    @Override
    public void should_return400_when_makingHttpRequestWithoutToken() throws Exception {
        ClientResponse response = descriptor.run(getId(), "");
        assertEquals(error(response.getEntity(String.class)), 403, response.getStatus());
    }
}
