/*
 * Copyright 2020 IBM Corp. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import org.junit.After;
import org.junit.Before;
import org.opengroup.osdu.register.model.Subscriber;
import org.opengroup.osdu.register.util.Config;
import org.opengroup.osdu.register.util.IBMTestUtils;
import org.opengroup.osdu.register.util.RestDescriptor;

import com.google.common.base.Strings;
import com.google.gson.Gson;
import com.sun.jersey.api.client.ClientResponse;

public class TestCreateSubscriberApi extends CreateSubscriberApiTest {

    @Before
    @Override
    public void setup() throws Exception {
        this.testUtils = new IBMTestUtils();
        super.setup();
    }

    @After
    @Override
    public void tearDown() {
        this.testUtils = null;
    }
    @Override
    protected void validate20XResponse(ClientResponse response, RestDescriptor descriptor) {
        String url = Config.Instance().PushUrl + "api/register/v1/test/challenge/1";
        String body = response.getEntity(String.class);
        Subscriber subscriber = new Gson().fromJson(body, Subscriber.class);
        assertEquals("My test listener.", subscriber.description);
        assertTrue(subscriber.createdBy, subscriber.createdBy.endsWith("opengroup.org"));
        assertEquals("My listener", subscriber.name);
        assertEquals("records-changed", subscriber.topic);
        assertFalse(Strings.isNullOrEmpty(subscriber.notificationId));
        assertEquals(url, subscriber.pushEndpoint);
    }
    
	@Override
	public void should_return400_when_makingHttpRequestWithoutToken() throws Exception {
		ClientResponse response = descriptor.run(getId(), "");
        assertEquals(error(response.getEntity(String.class)), 403, response.getStatus());
	}
}
